@@ -27,10 +27,10 @@ import com.ait.lienzo.shared.core.types.EventPropagationMode;
 import org.jboss.errai.ui.client.local.spi.TranslationService;
 import org.kie.workbench.common.dmn.api.definition.HasExpression;
 import org.kie.workbench.common.dmn.api.definition.HasName;
-import org.kie.workbench.common.dmn.api.definition.v1_1.Context;
-import org.kie.workbench.common.dmn.api.definition.v1_1.ContextEntry;
-import org.kie.workbench.common.dmn.api.definition.v1_1.DMNModelInstrumentedBase;
-import org.kie.workbench.common.dmn.api.definition.v1_1.InformationItem;
+import org.kie.workbench.common.dmn.api.definition.model.Context;
+import org.kie.workbench.common.dmn.api.definition.model.ContextEntry;
+import org.kie.workbench.common.dmn.api.definition.model.DMNModelInstrumentedBase;
+import org.kie.workbench.common.dmn.api.definition.model.InformationItem;
 import org.kie.workbench.common.dmn.api.property.dmn.Name;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.context.AddContextEntryCommand;
 import org.kie.workbench.common.dmn.client.commands.expressions.types.context.ClearExpressionTypeCommand;
@@ -40,7 +40,7 @@ import org.kie.workbench.common.dmn.client.editors.expressions.types.ExpressionE
 import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionColumn;
 import org.kie.workbench.common.dmn.client.editors.expressions.types.undefined.UndefinedExpressionGrid;
 import org.kie.workbench.common.dmn.client.editors.expressions.util.SelectionUtils;
-import org.kie.workbench.common.dmn.client.editors.types.NameAndDataTypePopoverView;
+import org.kie.workbench.common.dmn.client.editors.types.ValueAndDataTypePopoverView;
 import org.kie.workbench.common.dmn.client.resources.i18n.DMNEditorConstants;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGrid;
 import org.kie.workbench.common.dmn.client.widgets.grid.BaseExpressionGridRenderer;
@@ -76,7 +76,7 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
                                                                                                                HasListSelectorControl {
 
     private final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier;
-    private final NameAndDataTypePopoverView.Presenter headerEditor;
+    private final ValueAndDataTypePopoverView.Presenter headerEditor;
 
     public ContextGrid(final GridCellTuple parent,
                        final Optional<String> nodeUUID,
@@ -98,7 +98,7 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
                        final boolean isOnlyVisualChangeAllowed,
                        final int nesting,
                        final Supplier<ExpressionEditorDefinitions> expressionEditorDefinitionsSupplier,
-                       final NameAndDataTypePopoverView.Presenter headerEditor) {
+                       final ValueAndDataTypePopoverView.Presenter headerEditor) {
         super(parent,
               nodeUUID,
               hasExpression,
@@ -148,35 +148,38 @@ public class ContextGrid extends BaseExpressionGrid<Context, ContextGridData, Co
     public void initialiseUiColumns() {
         final List<GridColumn.HeaderMetaData> headerMetaData = new ArrayList<>();
         final ContextGridRowNumberColumn rowNumberColumn = new ContextGridRowNumberColumn(headerMetaData,
-                                                                                          getAndSetInitialWidth(0, ContextGridRowNumberColumn.DEFAULT_WIDTH));
+                                                                                          getAndSetInitialWidth(ContextUIModelMapperHelper.ROW_COLUMN_INDEX,
+                                                                                                                ContextGridRowNumberColumn.DEFAULT_WIDTH));
         if (nesting == 0) {
             rowNumberColumn.getHeaderMetaData().add(new BaseHeaderMetaData("#"));
             headerMetaData.add(new NameColumnHeaderMetaData(hasExpression,
                                                             hasName,
-                                                            clearDisplayNameConsumer(true),
-                                                            setDisplayNameConsumer(true),
+                                                            clearValueConsumer(true, new Name()),
+                                                            setValueConsumer(true),
                                                             setTypeRefConsumer(),
+                                                            translationService,
                                                             cellEditorControls,
                                                             headerEditor,
-                                                            Optional.of(translationService.getTranslation(DMNEditorConstants.ContextEditor_EditExpression)),
                                                             listSelector,
                                                             this::getHeaderItems,
                                                             this::onItemSelected));
         }
 
         final NameColumn nameColumn = new NameColumn(headerMetaData,
-                                                     getAndSetInitialWidth(1, DMNGridColumn.DEFAULT_WIDTH),
+                                                     getAndSetInitialWidth(ContextUIModelMapperHelper.NAME_COLUMN_INDEX,
+                                                                           DMNGridColumn.DEFAULT_WIDTH),
                                                      this,
                                                      (rowIndex) -> rowIndex != getModel().getRowCount() - 1,
-                                                     clearDisplayNameConsumer(false),
-                                                     setDisplayNameConsumer(false),
+                                                     clearValueConsumer(false, new Name()),
+                                                     setValueConsumer(false),
                                                      setTypeRefConsumer(),
+                                                     translationService,
                                                      cellEditorControls,
-                                                     headerEditor,
-                                                     Optional.of(translationService.getTranslation(DMNEditorConstants.ContextEditor_EditContextEntry)));
+                                                     headerEditor);
         final ExpressionEditorColumn expressionColumn = new ExpressionEditorColumn(gridLayer,
                                                                                    headerMetaData,
-                                                                                   getAndSetInitialWidth(2, UndefinedExpressionColumn.DEFAULT_WIDTH),
+                                                                                   getAndSetInitialWidth(ContextUIModelMapperHelper.EXPRESSION_COLUMN_INDEX,
+                                                                                                         UndefinedExpressionColumn.DEFAULT_WIDTH),
                                                                                    this);
 
         model.appendColumn(rowNumberColumn);
