@@ -20,7 +20,6 @@ import java.util.List;
 import java.util.Optional;
 import java.util.stream.Stream;
 
-import org.junit.Assume;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -240,15 +239,8 @@ public class AddInputClauseCommandTest {
                      inputClause.getParent());
     }
 
-    /**
-     * The test is skipped on jdk 11 due to https://issues.jboss.org/browse/DROOLS-3777
-     */
-    @Test(expected = ArrayIndexOutOfBoundsException.class)
-    public void testGraphCommandUndoNoInputClauseColumns() throws Exception {
-
-        final String javaVersion = "11";
-        final String javaVersionPropertyKey = "java.version";
-        Assume.assumeFalse(System.getProperty(javaVersionPropertyKey).contains(javaVersion));
+    @Test(expected = IndexOutOfBoundsException.class)
+    public void testGraphCommandUndoNoInputClauseColumns() {
 
         makeCommand(DecisionTableUIModelMapperHelper.ROW_INDEX_COLUMN_COUNT);
 
