@@ -15,6 +15,7 @@
  */
 package org.kie.workbench.common.dmn.showcase.client.editor;
 
+import java.util.Objects;
 import java.util.Optional;
 
 import javax.enterprise.context.ApplicationScoped;
@@ -23,10 +24,14 @@ import javax.enterprise.event.Observes;
 import javax.enterprise.inject.Default;
 import javax.inject.Inject;
 
+import org.appformer.client.context.Channel;
+import org.appformer.client.context.EditorContextProvider;
 import org.jboss.errai.ioc.client.api.ManagedInstance;
 import org.kie.workbench.common.dmn.api.qualifiers.DMNEditor;
 import org.kie.workbench.common.dmn.client.docks.navigator.DecisionNavigatorDock;
 import org.kie.workbench.common.dmn.client.editors.expressions.ExpressionEditorView;
+import org.kie.workbench.common.dmn.client.editors.included.IncludedModelsPage;
+import org.kie.workbench.common.dmn.client.editors.included.imports.IncludedModelsPageStateProviderImpl;
 import org.kie.workbench.common.dmn.client.editors.search.DMNEditorSearchIndex;
 import org.kie.workbench.common.dmn.client.editors.search.DMNSearchableElement;
 import org.kie.workbench.common.dmn.client.editors.types.DataTypePageTabActiveEvent;
@@ -39,6 +44,7 @@ import org.kie.workbench.common.dmn.webapp.common.client.docks.preview.PreviewDi
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.AbstractDMNDiagramEditor;
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.DMNEditorMenuSessionItems;
 import org.kie.workbench.common.dmn.webapp.kogito.common.client.editor.DMNProjectToolbarStateHandler;
+import org.kie.workbench.common.dmn.webapp.kogito.common.client.tour.GuidedTourBridgeInitializer;
 import org.kie.workbench.common.kogito.client.editor.MultiPageEditorContainerView;
 import org.kie.workbench.common.kogito.webapp.base.client.editor.KogitoScreen;
 import org.kie.workbench.common.stunner.client.widgets.presenters.session.impl.SessionEditorPresenter;
@@ -74,6 +80,9 @@ import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
 
+import static org.appformer.client.context.Channel.DEFAULT;
+import static org.appformer.client.context.Channel.VSCODE;
+
 @DiagramEditor
 @ApplicationScoped
 @WorkbenchClientEditor(identifier = AbstractDMNDiagramEditor.EDITOR_ID)
@@ -112,7 +121,11 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor implements Kogito
                             final KogitoClientDiagramService diagramServices,
                             final MonacoFEELInitializer feelInitializer,
                             final CanvasFileExport canvasFileExport,
-                            final Promises promises) {
+                            final Promises promises,
+                            final IncludedModelsPage includedModelsPage,
+                            final IncludedModelsPageStateProviderImpl importsPageProvider,
+                            final EditorContextProvider contextProvider,
+                            final GuidedTourBridgeInitializer guidedTourBridgeInitializer) {
         super(view,
               fileMenuBuilder,
               placeManager,
@@ -142,7 +155,11 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor implements Kogito
               diagramServices,
               feelInitializer,
               canvasFileExport,
-              promises);
+              promises,
+              includedModelsPage,
+              importsPageProvider,
+              contextProvider,
+              guidedTourBridgeInitializer);
     }
 
     @Override
@@ -159,6 +176,10 @@ public class DMNDiagramEditor extends AbstractDMNDiagramEditor implements Kogito
             expressionEditor.setToolbarStateHandler(new DMNProjectToolbarStateHandler(getMenuSessionItems()));
             decisionNavigatorDock.setupCanvasHandler(c);
             dataTypesPage.reload();
+            final Channel channel = contextProvider.getChannel();
+            if (Objects.equals(channel, DEFAULT) || Objects.equals(channel, VSCODE)) {
+                includedModelsPage.setup(importsPageProvider.withDiagram(c.getDiagram()));
+            }
         });
     }
 
