@@ -72,7 +72,11 @@ public class DMNDiagramEditorTest extends AbstractDMNDiagramEditorTest {
                                     clientDiagramService,
                                     feelInitializer,
                                     canvasFileExport,
-                                    new SyncPromises()) {
+                                    new SyncPromises(),
+                                    includedModelsPage,
+                                    importsPageProvider,
+                                    contextProvider,
+                                    guidedTourBridgeInitializer) {
             @Override
             protected ElementWrapperWidget<?> getWidget(final HTMLElement element) {
                 return searchBarComponentWidget;
