@@ -17,7 +17,6 @@
 package org.kie.workbench.common.forms.editor.client.editor.changes;
 
 import java.util.ArrayList;
-import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
 import java.util.stream.Collectors;
@@ -27,6 +26,7 @@ import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
 
 import org.jboss.errai.ioc.client.container.IOC;
+import org.kie.soup.commons.validation.PortablePreconditions;
 import org.kie.workbench.common.forms.editor.client.editor.changes.conflicts.ConflictsHandler;
 import org.kie.workbench.common.forms.editor.client.editor.changes.conflicts.element.ConflictElement;
 import org.kie.workbench.common.forms.editor.client.editor.changes.displayers.conflicts.ConflictsDisplayer;
@@ -36,7 +36,6 @@ import org.kie.workbench.common.forms.editor.model.FormModelerContent;
 import org.kie.workbench.common.forms.model.FieldDefinition;
 import org.kie.workbench.common.forms.model.FormModel;
 import org.kie.workbench.common.forms.service.shared.FieldManager;
-import org.uberfire.commons.validation.PortablePreconditions;
 import org.uberfire.mvp.Command;
 
 @Dependent
@@ -83,12 +82,13 @@ public class ChangesNotificationDisplayer implements ChangesNotificationDisplaye
         allHandlers.add(handler);
     }
 
-    public void show(FormModelerContent content,
-                     Command onClose) {
-        PortablePreconditions.checkNotNull("content",
-                                           content);
-        PortablePreconditions.checkNotNull("onClose",
-                                           onClose);
+    public void show(FormModelerContent content, Command onClose) {
+        PortablePreconditions.checkNotNull("content", content);
+        PortablePreconditions.checkNotNull("onClose", onClose);
+
+        if(content.getError() != null) {
+            return;
+        }
 
         this.content = content;
         this.onClose = onClose;
