@@ -31,7 +31,7 @@ import org.kie.soup.commons.util.Sets;
 import org.kie.workbench.common.profile.api.preferences.ProfileService;
 import org.kie.workbench.common.widgets.client.handlers.workbench.configuration.LanguageConfigurationHandler;
 import org.kie.workbench.common.widgets.client.handlers.workbench.configuration.WorkbenchConfigurationPresenter;
-import org.kie.workbench.common.workbench.client.PerspectiveIds;
+import  org.kie.workbench.common.services.shared.resources.PerspectiveIds;
 import org.kie.workbench.common.workbench.client.admin.resources.i18n.PreferencesConstants;
 import org.kie.workbench.common.workbench.client.authz.WorkbenchFeatures;
 import org.kie.workbench.common.workbench.client.resources.i18n.DefaultWorkbenchConstants;
@@ -51,9 +51,9 @@ import org.uberfire.security.ResourceRef;
 import org.uberfire.security.authz.AuthorizationManager;
 import org.uberfire.workbench.model.ActivityResourceType;
 
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.ADMIN;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.GUVNOR_M2REPO;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.SECURITY_MANAGEMENT;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.ADMIN;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.GUVNOR_M2REPO;
+import static org.kie.workbench.common.services.shared.resources.PerspectiveIds.SECURITY_MANAGEMENT;
 
 public class DefaultAdminPageHelper {
 
@@ -95,6 +95,8 @@ public class DefaultAdminPageHelper {
     @Inject
     Caller<ProfileService> profileService;
 
+    private static final String ADVANCED_CATEGORY = "advanced";
+
     public void setup() {
         setup(true,
               true,
@@ -120,6 +122,10 @@ public class DefaultAdminPageHelper {
         addSSHKeys();
         addProfilePreferences();
         addDataTransferPerspective();
+
+        if (libraryPreferencesEnabled) {
+            addArchetypesPerspective();
+        }
     }
 
     private void addDataTransferPerspective() {
@@ -149,12 +155,12 @@ public class DefaultAdminPageHelper {
         profileService.call((Boolean force) -> {
             if (canEditProfilePreferences && !force) {
                 adminPage.addPreference("root",
-                        "ProfilePreferences",
-                        translationService.format(PreferencesConstants.ProfilePreferences_Title),
-                        new Sets.Builder().add("fa").add("fa-list").build(),
-                        "advanced",
-                        scopeFactory.createScope(GuvnorPreferenceScopes.GLOBAL),
-                        AdminPageOptions.WITH_BREADCRUMBS);
+                                        "ProfilePreferences",
+                                        translationService.format(PreferencesConstants.ProfilePreferences_Title),
+                                        new Sets.Builder().add("fa").add("fa-list").build(),
+                                        ADVANCED_CATEGORY,
+                                        scopeFactory.createScope(GuvnorPreferenceScopes.GLOBAL),
+                                        AdminPageOptions.WITH_BREADCRUMBS);
             }
         }).isForce();
     }
@@ -184,7 +190,7 @@ public class DefaultAdminPageHelper {
             adminPage.addTool("root",
                               constants.ExperimentalSettings(),
                               new Sets.Builder().add("fa").add("fa-flask").build(),
-                              "advanced",
+                              ADVANCED_CATEGORY,
                               () -> {
                                   final Command accessExperimentals = () -> placeManager.goTo(PerspectiveIds.EXPERIMENTAL_FEATURES);
                                   accessExperimentals.execute();
@@ -343,6 +349,22 @@ public class DefaultAdminPageHelper {
         }
     }
 
+    private void addArchetypesPerspective() {
+        if (hasAccessToPerspective(PerspectiveIds.ARCHETYPE_MANAGEMENT)) {
+            adminPage.addTool("root",
+                              constants.Archetypes(),
+                              new Sets.Builder().add("fa").add("fa-file-code-o").build(),
+                              ADVANCED_CATEGORY,
+                              () -> {
+                                  final Command accessArchetypeMgmt = () -> placeManager.goTo(PerspectiveIds.ARCHETYPE_MANAGEMENT);
+                                  accessArchetypeMgmt.execute();
+                                  addAdminBreadcrumbs(PerspectiveIds.ARCHETYPE_MANAGEMENT,
+                                                      constants.Archetypes(),
+                                                      accessArchetypeMgmt);
+                              });
+        }
+    }
+
     private void addGlobalPreferences(boolean libraryPreferencesEnabled,
                                       boolean artifactRepositoryPreferencesEnabled) {
         final boolean canEditGlobalPreferences = authorizationManager.authorize(WorkbenchFeatures.EDIT_GLOBAL_PREFERENCES,
@@ -381,14 +403,14 @@ public class DefaultAdminPageHelper {
                                 AdminPageOptions.WITH_BREADCRUMBS);
 
         adminPage.addTool("root",
-                                constants.ServiceTasksAdministration(),
+                                constants.CustomTasksAdministration(),
                                 new Sets.Builder().add("fa").add("fa-cogs").build(),
                                 "services",
                                 () -> {
                                     final Command accessServiceTasks = () -> placeManager.goTo(PerspectiveIds.SERVICE_TASK_ADMIN);
                                     accessServiceTasks.execute();
                                     addAdminBreadcrumbs(PerspectiveIds.SERVICE_TASK_ADMIN,
-                                                        constants.ServiceTasksAdministration(),
+                                                        constants.CustomTasksAdministration(),
                                                         accessServiceTasks);
                                 });
     }
