@@ -16,43 +16,38 @@
 
 package org.kie.workbench.common.stunner.client.lienzo.components.toolbox.actions;
 
-import java.util.function.BiConsumer;
-import java.util.function.Consumer;
-import java.util.function.Supplier;
+import java.util.Collections;
 
-import com.ait.lienzo.client.core.event.NodeMouseClickEvent;
-import com.ait.lienzo.client.core.event.NodeMouseClickHandler;
 import com.ait.lienzo.client.core.event.NodeMouseEnterEvent;
 import com.ait.lienzo.client.core.event.NodeMouseEnterHandler;
 import com.ait.lienzo.client.core.event.NodeMouseExitEvent;
 import com.ait.lienzo.client.core.event.NodeMouseExitHandler;
 import com.ait.lienzo.client.core.shape.Group;
 import com.ait.lienzo.client.core.shape.Layer;
+import com.ait.lienzo.client.core.shape.toolbox.grid.Point2DGrid;
+import com.ait.lienzo.client.core.shape.toolbox.items.DecoratorItem;
+import com.ait.lienzo.client.core.shape.toolbox.items.LayerToolbox;
+import com.ait.lienzo.client.core.shape.toolbox.items.TooltipItem;
+import com.ait.lienzo.client.core.shape.toolbox.items.decorator.BoxDecorator;
+import com.ait.lienzo.client.core.shape.toolbox.items.decorator.DecoratorsFactory;
+import com.ait.lienzo.client.core.shape.toolbox.items.impl.ButtonItemImpl;
+import com.ait.lienzo.client.core.shape.toolbox.items.impl.ButtonsFactory;
+import com.ait.lienzo.client.core.shape.toolbox.items.impl.ItemsToolboxHighlight;
+import com.ait.lienzo.client.core.shape.toolbox.items.impl.ToolboxFactory;
+import com.ait.lienzo.client.core.shape.toolbox.items.impl.WiresShapeToolbox;
+import com.ait.lienzo.client.core.shape.toolbox.items.tooltip.ToolboxTextTooltip;
+import com.ait.lienzo.client.core.shape.toolbox.items.tooltip.TooltipFactory;
 import com.ait.lienzo.client.core.shape.wires.WiresShape;
 import com.ait.lienzo.client.core.types.BoundingBox;
 import com.ait.lienzo.client.core.types.Point2D;
 import com.ait.lienzo.shared.core.types.Direction;
-import com.google.gwt.event.dom.client.MouseEvent;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvas;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresCanvasView;
 import org.kie.workbench.common.stunner.client.lienzo.canvas.wires.WiresLayer;
 import org.kie.workbench.common.stunner.client.lienzo.components.glyph.LienzoGlyphRenderers;
 import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvas;
 import org.kie.workbench.common.stunner.core.client.components.toolbox.actions.ActionsToolbox;
-import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseClickEvent;
 import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
-import org.kie.workbench.common.stunner.lienzo.toolbox.grid.Point2DGrid;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.DecoratorItem;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.LayerToolbox;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.TooltipItem;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.decorator.BoxDecorator;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.decorator.DecoratorsFactory;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.impl.ButtonItemImpl;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.impl.ButtonsFactory;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.impl.ToolboxFactory;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.impl.WiresShapeToolbox;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.tooltip.ToolboxTextTooltip;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.tooltip.TooltipFactory;
 import org.mockito.ArgumentCaptor;
 
 import static org.mockito.Matchers.any;
@@ -83,6 +78,7 @@ public abstract class AbstractActionsToolboxViewTest {
     protected ButtonItemImpl buttonItem;
     protected BoxDecorator boxDecorator;
     protected ToolboxTextTooltip toolboxTooltip;
+    protected ItemsToolboxHighlight toolboxHighlight;
     protected Group glyphView;
 
     @SuppressWarnings("unchecked")
@@ -104,6 +100,7 @@ public abstract class AbstractActionsToolboxViewTest {
         buttonItem = mock(ButtonItemImpl.class);
         boxDecorator = mock(BoxDecorator.class);
         toolboxTooltip = mock(ToolboxTextTooltip.class);
+        toolboxHighlight = mock(ItemsToolboxHighlight.class);
         glyphView = mock(Group.class);
         when(canvas.getView()).thenReturn(canvasView);
         when(canvasView.getLayer()).thenReturn(wiresLayer);
@@ -117,7 +114,7 @@ public abstract class AbstractActionsToolboxViewTest {
         when(buttonsFactory.button(any(Group.class))).thenReturn(buttonItem);
         when(decoratorsFactory.box()).thenReturn(boxDecorator);
         when(tooltipFactory.forToolbox(any(LayerToolbox.class))).thenReturn(toolboxTooltip);
-        when(boxDecorator.configure(any(Consumer.class))).thenReturn(boxDecorator);
+        when(boxDecorator.configure(any(com.ait.tooling.common.api.java.util.function.Consumer.class))).thenReturn(boxDecorator);
         when(boxDecorator.copy()).thenReturn(boxDecorator);
         when(toolboxViewBoundingBox.getWidth()).thenReturn(300d);
         when(toolboxViewBoundingBox.getHeight()).thenReturn(600d);
@@ -127,19 +124,20 @@ public abstract class AbstractActionsToolboxViewTest {
         when(toolboxView.offset(any(Point2D.class))).thenReturn(toolboxView);
         when(toolboxView.at(any(Direction.class))).thenReturn(toolboxView);
         when(toolboxView.grid(any(Point2DGrid.class))).thenReturn(toolboxView);
-        when(toolboxView.useShowExecutor(any(BiConsumer.class))).thenReturn(toolboxView);
-        when(toolboxView.useHideExecutor(any(BiConsumer.class))).thenReturn(toolboxView);
+        when(toolboxView.useShowExecutor(any(com.ait.tooling.common.api.java.util.function.BiConsumer.class))).thenReturn(toolboxView);
+        when(toolboxView.useHideExecutor(any(com.ait.tooling.common.api.java.util.function.BiConsumer.class))).thenReturn(toolboxView);
         when(buttonItem.tooltip(any(TooltipItem.class))).thenReturn(buttonItem);
         when(buttonItem.decorate(any(DecoratorItem.class))).thenReturn(buttonItem);
         when(buttonItem.onMouseEnter(any(NodeMouseEnterHandler.class))).thenReturn(buttonItem);
         when(buttonItem.onMouseExit(any(NodeMouseExitHandler.class))).thenReturn(buttonItem);
-        when(buttonItem.onClick(any(NodeMouseClickHandler.class))).thenReturn(buttonItem);
+        when(buttonItem.onClick(any(com.ait.tooling.common.api.java.util.function.Consumer.class))).thenReturn(buttonItem);
         when(toolboxTooltip.at(any(Direction.class))).thenReturn(toolboxTooltip);
         when(toolboxTooltip.towards(any(Direction.class))).thenReturn(toolboxTooltip);
         when(toolboxTooltip.setText(anyString())).thenReturn(toolboxTooltip);
-        when(toolboxTooltip.forComputedBoundingBox(any(Supplier.class))).thenReturn(toolboxTooltip);
-        when(toolboxTooltip.withText(any(Consumer.class))).thenReturn(toolboxTooltip);
-        when(toolbox.size()).thenReturn(2);
+        when(toolboxTooltip.forComputedBoundingBox(any(com.ait.tooling.common.api.java.util.function.Supplier.class))).thenReturn(toolboxTooltip);
+        when(toolboxTooltip.withText(any(com.ait.tooling.common.api.java.util.function.Consumer.class))).thenReturn(toolboxTooltip);
+        when(toolbox.size()).thenReturn(0);
+        when(toolbox.iterator()).thenReturn(Collections.emptyIterator());
         when(glyphRenderers.render(any(Glyph.class),
                                    anyDouble(),
                                    anyDouble()))
@@ -147,10 +145,10 @@ public abstract class AbstractActionsToolboxViewTest {
     }
 
     @SuppressWarnings("unchecked")
-    protected void testAddButton(final Consumer<MouseClickEvent> clickEventConsumer) {
+    protected void testAddButton(final String title) {
         // Verify tootlip.
         verify(toolboxTooltip,
-               times(1)).createItem(eq("title1"));
+               times(1)).createItem(eq(title));
         verify(buttonItem,
                times(1)).tooltip(any(TooltipItem.class));
         // Verify mouse enter.
@@ -172,17 +170,6 @@ public abstract class AbstractActionsToolboxViewTest {
         final NodeMouseExitEvent mouseExitEvent = mock(NodeMouseExitEvent.class);
         exitHandler.onNodeMouseExit(mouseExitEvent);
         verify(canvasView,
-               times(1)).setCursor(eq(AbstractCanvas.Cursors.AUTO));
-        // Verify mouse click.
-        final ArgumentCaptor<NodeMouseClickHandler> clickHandlerArgumentCaptor =
-                ArgumentCaptor.forClass(NodeMouseClickHandler.class);
-        verify(buttonItem,
-               times(1)).onClick(clickHandlerArgumentCaptor.capture());
-        final NodeMouseClickHandler clickHandler = clickHandlerArgumentCaptor.getValue();
-        final NodeMouseClickEvent mouseClickEvent = mock(NodeMouseClickEvent.class);
-        when(mouseClickEvent.getMouseEvent()).thenReturn(mock(MouseEvent.class));
-        clickHandler.onNodeMouseClick(mouseClickEvent);
-        verify(clickEventConsumer,
-               times(1)).accept(any(MouseClickEvent.class));
+               times(1)).setCursor(eq(AbstractCanvas.Cursors.DEFAULT));
     }
 }
