@@ -18,15 +18,15 @@ package org.kie.workbench.common.stunner.client.lienzo.components.toolbox.action
 
 import java.util.function.Consumer;
 
+import com.ait.lienzo.client.core.shape.toolbox.grid.AutoGrid;
+import com.ait.lienzo.client.core.shape.toolbox.grid.Point2DGrid;
+import com.ait.lienzo.client.core.shape.toolbox.items.ButtonItem;
 import com.ait.lienzo.test.LienzoMockitoTestRunner;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.core.client.shape.view.event.MouseClickEvent;
 import org.kie.workbench.common.stunner.core.definition.shape.Glyph;
-import org.kie.workbench.common.stunner.lienzo.toolbox.grid.AutoGrid;
-import org.kie.workbench.common.stunner.lienzo.toolbox.grid.Point2DGrid;
-import org.kie.workbench.common.stunner.lienzo.toolbox.items.ButtonItem;
 import org.mockito.ArgumentCaptor;
 
 import static org.junit.Assert.assertEquals;
@@ -90,9 +90,8 @@ public class CommonActionsToolboxViewTest
         doInit();
         final Consumer<MouseClickEvent> eventConsumer = mock(Consumer.class);
         tested.addButton(mock(Glyph.class),
-                         "title1",
-                         eventConsumer);
-        super.testAddButton(eventConsumer);
+                         "title1");
+        super.testAddButton("title1");
     }
 
     @Test
