@@ -16,13 +16,14 @@
 
 package org.kie.workbench.common.stunner.shapes.client;
 
-import org.kie.workbench.common.stunner.shapes.client.view.ConnectorView;
+import org.kie.workbench.common.stunner.shapes.client.view.AbstractConnectorView;
 import org.kie.workbench.common.stunner.shapes.def.ConnectorShapeDef;
 
-public class ConnectorShape<W> extends BasicConnectorShape<W, ConnectorShapeDef<W>, ConnectorView> {
+public class ConnectorShape<W>
+        extends BasicConnectorShape<W, ConnectorShapeDef<W, AbstractConnectorView>, AbstractConnectorView> {
 
-    public ConnectorShape(final ConnectorShapeDef<W> shapeDef,
-                          final ConnectorView view) {
+    public ConnectorShape(final ConnectorShapeDef<W, AbstractConnectorView> shapeDef,
+                          final AbstractConnectorView view) {
         super(shapeDef,
               view);
     }
