@@ -46,4 +46,19 @@ public class AddNodeCommand extends AbstractCanvasGraphCommand {
         return new AddCanvasNodeCommand(candidate,
                                         shapeSetId);
     }
+
+    public Node getCandidate() {
+        return candidate;
+    }
+
+    public String getShapeSetId() {
+        return shapeSetId;
+    }
+
+    @Override
+    public String toString() {
+        return getClass().getSimpleName() +
+                " [candidate=" + toUUID(getCandidate()) + "," +
+                "shapeSet=" + getShapeSetId() + "]";
+    }
 }
