@@ -80,14 +80,14 @@ public class ToolboxControlTest {
 
     @Test
     public void testEnable() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         verify(delegated,
-               times(1)).enable(eq(canvasHandler));
+               times(1)).init(eq(canvasHandler));
     }
 
     @Test
     public void testRegister() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         tested.register(element);
         verify(delegated,
                times(1)).register(eq(element));
@@ -97,7 +97,7 @@ public class ToolboxControlTest {
 
     @Test
     public void testDeRegister() {
-        tested.enable(canvasHandler);
+        tested.init(canvasHandler);
         tested.deregister(element);
         verify(delegated,
                times(1)).deregister(eq(element));
@@ -105,13 +105,6 @@ public class ToolboxControlTest {
                never()).register(any(Element.class));
     }
 
-    @Test
-    public void testDisable() {
-        tested.disable();
-        verify(delegated,
-               times(1)).disable();
-    }
-
     @Test
     public void testGetToolboxes() {
         tested.getToolboxes(element);
@@ -132,12 +125,27 @@ public class ToolboxControlTest {
                never()).destroy();
     }
 
+    @Test
+    public void testElementSelectedEventCache() {
+        final String uuid = "uuid1";
+        when(element.getUUID()).thenReturn(uuid);
+        final CanvasSelectionEvent event = new CanvasSelectionEvent(canvasHandler,
+                                                                    element.getUUID());
+        tested.onCanvasSelectionEvent(event);
+        tested.onCanvasSelectionEvent(event);
+        // Verify if it has been selected and called show on every selection event.
+        verify(delegated,
+               times(2)).show(eq(uuid));
+        verify(delegated,
+               never()).destroy();
+    }
+
     @Test
     public void testClearSelectionEvent() {
         final CanvasClearSelectionEvent event = new CanvasClearSelectionEvent(canvasHandler);
         tested.onCanvasClearSelectionEvent(event);
         verify(delegated,
-               times(1)).destroy();
+               times(1)).destroyToolboxes();
         verify(delegated,
                never()).show(any(Element.class));
         verify(delegated,
@@ -154,7 +162,7 @@ public class ToolboxControlTest {
                                                                           shape);
         tested.onCanvasShapeRemovedEvent(event);
         verify(delegated,
-               times(1)).destroy();
+               times(1)).hideAndDestroyToolboxes();
         verify(delegated,
                never()).show(any(Element.class));
         verify(delegated,
