@@ -16,9 +16,6 @@
 
 package org.kie.workbench.common.stunner.core.client.util;
 
-import java.util.Arrays;
-import java.util.List;
-
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
@@ -29,17 +26,17 @@ import org.kie.workbench.common.stunner.core.client.canvas.AbstractCanvasHandler
 import org.kie.workbench.common.stunner.core.client.shape.EdgeShape;
 import org.kie.workbench.common.stunner.core.client.shape.MutationContext;
 import org.kie.workbench.common.stunner.core.client.shape.Shape;
+import org.kie.workbench.common.stunner.core.client.shape.ShapeViewExtStub;
 import org.kie.workbench.common.stunner.core.client.shape.impl.ConnectorShape;
 import org.kie.workbench.common.stunner.core.client.shape.view.ShapeView;
-import org.kie.workbench.common.stunner.core.graph.content.view.ControlPoint;
-import org.kie.workbench.common.stunner.core.graph.content.view.ControlPointImpl;
+import org.kie.workbench.common.stunner.core.graph.content.Bounds;
 import org.kie.workbench.common.stunner.core.graph.processing.index.Index;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
 
-import static org.junit.Assert.assertEquals;
 import static org.mockito.Matchers.eq;
 import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
 import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
@@ -70,10 +67,6 @@ public class ShapeUtilsTest {
 
     private TestingGraphInstanceBuilder.TestGraph2 instance2;
 
-    private ControlPoint controlPoint1;
-
-    private List<ControlPoint> controlPointList;
-
     @Before
     @SuppressWarnings("unchecked")
     public void setup() throws Exception {
@@ -88,11 +81,6 @@ public class ShapeUtilsTest {
         when(canvas.getShape(eq(e2))).thenReturn(edge2Shape);
         when(edge1Shape.getShapeView()).thenReturn(edge1ShapeView);
         when(edge2Shape.getShapeView()).thenReturn(edge2ShapeView);
-
-        controlPoint1 = new ControlPointImpl(0, 0);
-        controlPointList = Arrays.asList(controlPoint1);
-        when(edge1Shape.getControlPoints()).thenReturn(controlPointList);
-        when(edge1Shape.addControlPoints(controlPoint1)).thenReturn(controlPointList);
     }
 
     @Test
@@ -131,22 +119,11 @@ public class ShapeUtilsTest {
     }
 
     @Test
-    public void testAddControlPoints() {
-        List<ControlPoint> addedControlPoints = ShapeUtils.addControlPoints(instance2.edge1, canvasHandler, controlPoint1);
-        verify(edge1Shape).addControlPoints(controlPoint1);
-        assertEquals(addedControlPoints, controlPointList);
-    }
-
-    @Test
-    public void testRemoveControlPoints() {
-        ShapeUtils.removeControlPoints(instance2.edge1, canvasHandler, controlPoint1);
-        verify(edge1Shape).removeControlPoints(controlPoint1);
-    }
-
-    @Test
-    public void testGetControlPoints() {
-        List<ControlPoint> controlPoints = ShapeUtils.getControlPoints(instance2.edge1, canvasHandler);
-        verify(edge1Shape).getControlPoints();
-        assertEquals(controlPoints, controlPointList);
+    public void testEnforceLocationConstraints() {
+        ShapeViewExtStub shape = spy(new ShapeViewExtStub());
+        Bounds bounds = mock(Bounds.class);
+        ShapeUtils.enforceLocationConstraints(shape,
+                                              bounds);
+        verify(shape, times(1)).setDragBounds(eq(bounds));
     }
 }
