@@ -41,6 +41,7 @@ import org.kie.workbench.common.stunner.core.domainobject.DomainObject;
 import org.kie.workbench.common.stunner.core.graph.Element;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.content.definition.Definition;
+import org.kie.workbench.common.stunner.core.graph.impl.EdgeImpl;
 import org.kie.workbench.common.stunner.core.graph.impl.NodeImpl;
 import org.kie.workbench.common.stunner.core.graph.processing.index.Index;
 import org.kie.workbench.common.stunner.core.util.DefinitionUtils;
@@ -62,6 +63,7 @@ import static org.mockito.Mockito.atMost;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
@@ -88,6 +90,8 @@ public class FormPropertiesWidgetTest {
     @Mock
     private FormsContainer formsContainer;
     @Mock
+    private FormsFlushManager formsFlushManager;
+    @Mock
     private TranslationService translationService;
     @Mock
     private EditorSession session;
@@ -105,6 +109,8 @@ public class FormPropertiesWidgetTest {
     private NodeImpl node;
     @Mock
     private NodeImpl node2;
+
+    private EdgeImpl edge;
     @Mock
     private Definition nodeContent;
     @Mock
@@ -160,6 +166,7 @@ public class FormPropertiesWidgetTest {
                                                formsCanvasSessionHandler,
                                                propertiesOpenedEvent,
                                                formsContainer,
+                                               formsFlushManager,
                                                translationService) {
             @Override
             protected void log(final Level level, final String message) {
@@ -170,6 +177,12 @@ public class FormPropertiesWidgetTest {
         doAnswer((i) -> i.getArguments()[0]).when(translationService).getTranslation(anyString());
     }
 
+    @Test
+    public void testInit() {
+        tested.init();
+        verify(formsFlushManager, times(1)).setCurrentContainer(formsContainer);
+    }
+
     @Test
     public void testShowEmpty() {
         when(canvasHandler.getDiagram()).thenReturn(null);
@@ -180,6 +193,7 @@ public class FormPropertiesWidgetTest {
         verify(formsCanvasSessionHandler).show(callback);
 
         verify(formsContainer, never()).render(anyString(), any(), any(), any(), any(), any());
+        verify(propertiesOpenedEvent, never()).fire(formPropertiesOpenedArgumentCaptor.capture());
     }
 
     /**
@@ -254,6 +268,7 @@ public class FormPropertiesWidgetTest {
                                                                             eq(fieldValue));
 
         verify(propertiesOpenedEvent).fire(formPropertiesOpenedArgumentCaptor.capture());
+
         final FormPropertiesOpened formPropertiesOpened = formPropertiesOpenedArgumentCaptor.getValue();
         assertThat(formPropertiesOpened.getUuid()).isEqualTo(DOMAIN_OBJECT_UUID);
         assertThat(formPropertiesOpened.getName()).isEqualTo(DOMAIN_OBJECT_TRANSLATION_KEY);
@@ -273,6 +288,7 @@ public class FormPropertiesWidgetTest {
         formRenderer.render(GRAPH_UUID, (Element) null, command);
 
         verify(formsContainer, never()).render(any(), any(), any(), any(), any(), any());
+        verify(propertiesOpenedEvent, never()).fire(formPropertiesOpenedArgumentCaptor.capture());
         verify(command, never()).execute();
     }
 
@@ -294,6 +310,12 @@ public class FormPropertiesWidgetTest {
         verify(formsContainer, atMost(1)).render(any(), any(), any(), any(), any(), any());
     }
 
+    @Test
+    public void testFireFormsPropertiesOpenedEvent() {
+        tested.fireFormsPropertiesOpenedEvent("", "");
+        verify(propertiesOpenedEvent, times(1)).fire(formPropertiesOpenedArgumentCaptor.capture());
+    }
+
     @Test
     public void testAreElementsPositionSame() {
         tested.init();
@@ -312,4 +334,47 @@ public class FormPropertiesWidgetTest {
         assertEquals("Value is not the same ", tested.areLastPositionsForSameElementSame(node), false);
         assertEquals("Value is not the same ", tested.areLastPositionsForSameElementSame(node2), true);
     }
+
+    @Test
+    public void testShowSwitchingBetweenElementAndDomainObject() {
+        tested.init();
+
+        verify(formsCanvasSessionHandler).setRenderer(formRendererArgumentCaptor.capture());
+        final FormsCanvasSessionHandler.FormRenderer formRenderer = formRendererArgumentCaptor.getValue();
+
+        final Command command = mock(Command.class);
+        when(formsCanvasSessionHandler.getDiagram()).thenReturn(diagram);
+        when(domainObject.getDomainObjectUUID()).thenReturn(DOMAIN_OBJECT_UUID);
+        when(domainObject.getDomainObjectNameTranslationKey()).thenReturn(DOMAIN_OBJECT_TRANSLATION_KEY);
+
+        formRenderer.render(GRAPH_UUID, node, command);
+        verify(formsContainer, times(1)).render(eq(GRAPH_UUID), eq(ROOT_UUID), eq(nodeDefObject), any(), any(), any());
+
+        formRenderer.render(GRAPH_UUID, domainObject, command);
+        verify(formsContainer, times(1)).render(eq(GRAPH_UUID), eq(DOMAIN_OBJECT_UUID), eq(domainObject), any(), any(), any());
+
+        formRenderer.render(GRAPH_UUID, node, command);
+        verify(formsContainer, times(2)).render(eq(GRAPH_UUID), eq(ROOT_UUID), eq(nodeDefObject), any(), any(), any());
+
+        formRenderer.render(GRAPH_UUID, domainObject, command);
+        verify(formsContainer, times(2)).render(eq(GRAPH_UUID), eq(DOMAIN_OBJECT_UUID), eq(domainObject), any(), any(), any());
+    }
+
+    @Test
+    public void testAreElementsPositionSameNotNodes() {
+        tested.init();
+
+        verify(formsCanvasSessionHandler).setRenderer(formRendererArgumentCaptor.capture());
+        final FormsCanvasSessionHandler.FormRenderer formRenderer = formRendererArgumentCaptor.getValue();
+
+        final Command command = mock(Command.class);
+        when(formsCanvasSessionHandler.getDiagram()).thenReturn(diagram);
+        edge = new EdgeImpl("edge1");
+        formRenderer.render(GRAPH_UUID, edge, command);
+
+        assertEquals("Value is not the same ", tested.areLastPositionsForSameElementSame(edge), false);
+
+        formRenderer.render(GRAPH_UUID, edge, command);
+        assertEquals("Value is not the same ", tested.areLastPositionsForSameElementSame(node), false);
+    }
 }
