@@ -16,6 +16,7 @@
 
 package org.kie.workbench.common.stunner.bpmn.client.documentation;
 
+import java.util.Collection;
 import java.util.Comparator;
 import java.util.List;
 import java.util.Map;
@@ -54,6 +55,8 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.GlobalV
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Package;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Version;
+import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.DefaultImport;
+import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.ImportsValue;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Height;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Radius;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dimensions.Width;
@@ -78,6 +81,7 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.task.DecisionNa
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.DmnModelName;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.IsMultipleInstance;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.Namespace;
+import org.kie.workbench.common.stunner.bpmn.definition.property.variables.AdvancedData;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.BaseProcessData;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.BaseProcessVariables;
 import org.kie.workbench.common.stunner.bpmn.definition.property.variables.HasProcessData;
@@ -89,10 +93,11 @@ import org.kie.workbench.common.stunner.bpmn.documentation.model.element.Element
 import org.kie.workbench.common.stunner.bpmn.documentation.model.element.ElementDetails;
 import org.kie.workbench.common.stunner.bpmn.documentation.model.element.ElementTotal;
 import org.kie.workbench.common.stunner.bpmn.documentation.model.general.General;
+import org.kie.workbench.common.stunner.bpmn.documentation.model.general.Imports;
 import org.kie.workbench.common.stunner.bpmn.documentation.model.general.ProcessOverview;
 import org.kie.workbench.common.stunner.bpmn.documentation.model.general.ProcessVariablesTotal;
+import org.kie.workbench.common.stunner.bpmn.workitem.CustomTask;
 import org.kie.workbench.common.stunner.bpmn.workitem.IconDefinition;
-import org.kie.workbench.common.stunner.bpmn.workitem.ServiceTask;
 import org.kie.workbench.common.stunner.bpmn.workitem.WorkItemDefinition;
 import org.kie.workbench.common.stunner.bpmn.workitem.WorkItemDefinitionRegistry;
 import org.kie.workbench.common.stunner.client.widgets.components.glyph.DOMGlyphRenderers;
@@ -191,7 +196,7 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
 
     private ProcessOverview getProcessOverview(final Optional<BPMNDiagramImpl> diagramModel,
                                                final Graph<?, Node> graph) {
-        return ProcessOverview.create(getGeneral(diagramModel), getAllProcessVariables(graph));
+        return ProcessOverview.create(getGeneral(diagramModel), getAllImports(graph), getAllProcessVariables(graph));
     }
 
     private General getGeneral(Optional<BPMNDiagramImpl> diagramModel) {
@@ -254,12 +259,37 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
                 .build();
     }
 
+    private Imports getAllImports(final Graph<?, Node> graph) {
+        final List<Imports.DefaultImport> defaultImports = getDiagramModel(graph)
+                .map(BPMNDiagramImpl::getDiagramSet)
+                .map(DiagramSet::getImports)
+                .filter(Objects::nonNull)
+                .map(org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.Imports::getValue)
+                .map(ImportsValue::getDefaultImports)
+                .flatMap(Collection::stream)
+                .map(DefaultImport::getClassName)
+                .map(Imports.DefaultImport::create)
+                .collect(Collectors.toList());
+
+        final List<Imports.WSDLImport> wsdlImports = getDiagramModel(graph)
+                .map(BPMNDiagram::getDiagramSet)
+                .map(DiagramSet::getImports)
+                .filter(Objects::nonNull)
+                .map(org.kie.workbench.common.stunner.bpmn.definition.property.diagram.imports.Imports::getValue)
+                .map(ImportsValue::getWSDLImports)
+                .flatMap(Collection::stream)
+                .map(wsdlImport -> Imports.WSDLImport.create(wsdlImport.getLocation(), wsdlImport.getNamespace()))
+                .collect(Collectors.toList());
+
+        return Imports.create(defaultImports, wsdlImports);
+    }
+
     private ProcessVariablesTotal getAllProcessVariables(final Graph<?, Node> graph) {
         //Computing Global, Process, Sub-Processes variables
         final List<Map.Entry> variables = Stream.concat(
                 getDiagramModel(graph)
-                        .map(BPMNDiagram::getDiagramSet)
-                        .map(DiagramSet::getGlobalVariables)
+                        .map(BPMNDiagram::getAdvancedData)
+                        .map(AdvancedData::getGlobalVariables)
                         .map(GlobalVariables::getValue),
                 StreamSupport.stream(graph.nodes().spliterator(), false)
                         .map(Node::getContent)
@@ -273,7 +303,7 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
                         .map(BaseProcessVariables::getValue))
                 .map(ProcessVariableSerializer::deserialize)
                 .flatMap(v -> v.entrySet().stream())
-                .sorted((e1, e2) -> e1.getKey().compareTo(e2.getKey()))
+                .sorted(Comparator.comparing(Map.Entry::getKey))
                 .collect(Collectors.toList());
 
         return ProcessVariablesTotal.create(variables.size(), variables.size(), JsConverter.fromEntries(variables));
@@ -376,6 +406,7 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
 
     /**
      * Basically replace all \n with <br> html tag.
+     *
      * @param input
      * @return
      */
@@ -391,6 +422,7 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
 
     /**
      * Properties that should be ignored on the documentation
+     *
      * @return
      */
     private static Map<String, Boolean> buildIgnoredPropertiesIds() {
@@ -431,11 +463,11 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
         private DefinitionHelper() {
 
             iconFactory = new Maps.Builder<Class, Function<Object, Optional<String>>>()
-                    .put(ServiceTask.class, def -> getServiceTaskIcon(def))
+                    .put(CustomTask.class, def -> getServiceTaskIcon(def))
                     .build();
 
             categoryFactory = new Maps.Builder<Class, Function<Object, Optional<String>>>()
-                    .put(ServiceTask.class, def -> getServiceTaskCategory(def))
+                    .put(CustomTask.class, def -> getServiceTaskCategory(def))
                     .build();
         }
 
@@ -463,9 +495,9 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
 
         private Optional<String> getServiceTaskIcon(Object definition) {
             return Optional.ofNullable(definition)
-                    .filter(def -> def instanceof ServiceTask)
-                    .map(def -> (ServiceTask) def)
-                    .map(ServiceTask::getName)
+                    .filter(def -> def instanceof CustomTask)
+                    .map(def -> (CustomTask) def)
+                    .map(org.kie.workbench.common.stunner.bpmn.workitem.CustomTask::getName)
                     .map(name -> Optional.ofNullable(workItemDefinitionRegistry
                                                              .get()
                                                              .get(name))
@@ -486,9 +518,9 @@ public class ClientBPMNDocumentationService implements BPMNDocumentationService
 
         private Optional<String> getServiceTaskCategory(Object definition) {
             return Optional.ofNullable(definition)
-                    .filter(def -> def instanceof ServiceTask)
-                    .map(def -> (ServiceTask) def)
-                    .map(ServiceTask::getName)
+                    .filter(def -> def instanceof CustomTask)
+                    .map(def -> (CustomTask) def)
+                    .map(org.kie.workbench.common.stunner.bpmn.workitem.CustomTask::getName)
                     .map(name -> Optional.ofNullable(workItemDefinitionRegistry
                                                              .get()
                                                              .get(name))
