@@ -17,11 +17,14 @@
 package org.kie.workbench.common.stunner.bpmn.client.forms.fields.assignmentsEditor;
 
 import java.util.ArrayList;
+import java.util.Collection;
 import java.util.Collections;
-import java.util.HashMap;
-import java.util.Iterator;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
+import java.util.stream.Collectors;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.inject.Inject;
@@ -34,61 +37,86 @@ import com.google.gwt.user.client.ui.Composite;
 import com.google.gwt.user.client.ui.HasValue;
 import org.gwtbootstrap3.client.ui.Button;
 import org.gwtbootstrap3.client.ui.TextBox;
-import org.jboss.errai.bus.client.api.BusErrorCallback;
-import org.jboss.errai.bus.client.api.base.MessageBuilder;
-import org.jboss.errai.bus.client.api.messaging.Message;
-import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.marshalling.client.Marshalling;
 import org.jboss.errai.ui.shared.api.annotations.DataField;
 import org.jboss.errai.ui.shared.api.annotations.EventHandler;
 import org.jboss.errai.ui.shared.api.annotations.Templated;
+import org.kie.workbench.common.stunner.bpmn.client.forms.DataTypeNamesService;
 import org.kie.workbench.common.stunner.bpmn.client.forms.fields.i18n.StunnerFormsClientFieldsConstants;
 import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentData;
+import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.AssignmentParser;
 import org.kie.workbench.common.stunner.bpmn.client.forms.fields.model.Variable;
 import org.kie.workbench.common.stunner.bpmn.client.forms.util.StringUtils;
+import org.kie.workbench.common.stunner.bpmn.client.util.VariableUtils;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDefinition;
-import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagramImpl;
 import org.kie.workbench.common.stunner.bpmn.definition.BaseTask;
-import org.kie.workbench.common.stunner.bpmn.definition.UserTask;
+import org.kie.workbench.common.stunner.bpmn.definition.BaseUserTask;
+import org.kie.workbench.common.stunner.bpmn.definition.DataObject;
 import org.kie.workbench.common.stunner.bpmn.definition.property.dataio.DataIOModel;
-import org.kie.workbench.common.stunner.bpmn.definition.property.variables.ProcessVariables;
-import org.kie.workbench.common.stunner.bpmn.service.DataTypesService;
+import org.kie.workbench.common.stunner.bpmn.util.DataObjectUtils;
 import org.kie.workbench.common.stunner.core.client.api.SessionManager;
+import org.kie.workbench.common.stunner.core.client.canvas.controls.SelectionControl;
+import org.kie.workbench.common.stunner.core.client.session.ClientSession;
+import org.kie.workbench.common.stunner.core.client.session.impl.EditorSession;
 import org.kie.workbench.common.stunner.core.diagram.Diagram;
 import org.kie.workbench.common.stunner.core.graph.Element;
+import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
+import org.kie.workbench.common.stunner.core.graph.util.GraphUtils;
+import org.uberfire.backend.vfs.Path;
 import org.uberfire.workbench.events.NotificationEvent;
 
 @Dependent
 @Templated
 public class AssignmentsEditorWidget extends Composite implements HasValue<String> {
 
-    @Inject
-    @DataField
-    private Button assignmentsButton;
-
-    @Inject
-    @DataField
-    private TextBox assignmentsTextBox;
-
+    public static final String DEFAULT_IGNORED_PROPERTY_NAMES = "GroupId,Skippable,Comment,Description,Priority,Content,TaskName,Locale,CreatedBy,NotCompletedReassign,NotStartedReassign,NotCompletedNotify,NotStartedNotify";
     @Inject
     protected ActivityDataIOEditor activityDataIOEditor;
-
-    @Inject
-    SessionManager canvasSessionManager;
-
     @Inject
     protected Event<NotificationEvent> notification;
-
-    private BPMNDefinition bpmnModel;
-
     protected String assignmentsInfo;
-
     protected boolean hasInputVars = false;
     protected boolean isSingleInputVar = false;
     protected boolean hasOutputVars = false;
     protected boolean isSingleOutputVar = false;
 
+    @Inject
+    SessionManager canvasSessionManager;
+    @Inject
+    @DataField
+    private Button assignmentsButton;
+    @Inject
+    @DataField
+    private TextBox assignmentsTextBox;
+    @Inject
+    private GraphUtils graphUtils;
+    @Inject
+    private DataTypeNamesService clientDataTypesService;
+    private BPMNDefinition bpmnModel;
+
+    AssignmentsEditorWidget(final BPMNDefinition bpmnModel,
+                            final String assignmentsInfo,
+                            final boolean hasInputVars,
+                            final boolean isSingleInputVar,
+                            final boolean hasOutputVars,
+                            final boolean isSingleOutputVar,
+                            final SessionManager canvasSessionManager,
+                            final GraphUtils graphUtils) {
+        this.bpmnModel = bpmnModel;
+        this.assignmentsInfo = assignmentsInfo;
+        this.hasInputVars = hasInputVars;
+        this.isSingleInputVar = isSingleInputVar;
+        this.hasOutputVars = hasOutputVars;
+        this.isSingleOutputVar = isSingleOutputVar;
+        this.canvasSessionManager = canvasSessionManager;
+        this.graphUtils = graphUtils;
+    }
+
+    public AssignmentsEditorWidget() {
+    }
+
+    // create bean to hold cache and inject to source
     @EventHandler("assignmentsButton")
     public void onClickAssignmentsButton(final ClickEvent clickEvent) {
         showAssignmentsDialog();
@@ -123,241 +151,21 @@ public class AssignmentsEditorWidget extends Composite implements HasValue<Strin
         }
     }
 
-    protected void setBPMNModel(final BPMNDefinition bpmnModel) {
-        this.bpmnModel = bpmnModel;
-
-        if (bpmnModel instanceof DataIOModel) {
-            DataIOModel dataIOModel = (DataIOModel) bpmnModel;
-            hasInputVars = dataIOModel.hasInputVars();
-            isSingleInputVar = dataIOModel.isSingleInputVar();
-            hasOutputVars = dataIOModel.hasOutputVars();
-            isSingleOutputVar = dataIOModel.isSingleOutputVar();
-        } else {
-            hasInputVars = false;
-            isSingleInputVar = false;
-            hasOutputVars = false;
-            isSingleOutputVar = false;
-        }
-    }
-
     protected void initTextBox() {
-        Map<String, String> assignmentsProperties = parseAssignmentsInfo();
-        String variableCountsString = getVariableCountsString(assignmentsProperties.get("datainput"),
-                                                              assignmentsProperties.get("datainputset"),
-                                                              assignmentsProperties.get("dataoutput"),
-                                                              assignmentsProperties.get("dataoutputset"),
+
+        Map<String, String> assignmentsProperties = AssignmentParser.parseAssignmentsInfo(assignmentsInfo);
+
+        String variableCountsString = getVariableCountsString(assignmentsProperties.get(AssignmentParser.DATAINPUT),
+                                                              assignmentsProperties.get(AssignmentParser.DATAINPUTSET),
+                                                              assignmentsProperties.get(AssignmentParser.DATAOUTPUT),
+                                                              assignmentsProperties.get(AssignmentParser.DATAOUTPUTSET),
                                                               getProcessVariables(),
-                                                              assignmentsProperties.get("assignments"),
+                                                              assignmentsProperties.get(AssignmentParser.ASSIGNMENTS),
                                                               getDisallowedPropertyNames());
         assignmentsTextBox.setText(variableCountsString);
     }
 
-    @Override
-    public HandlerRegistration addValueChangeHandler(final ValueChangeHandler<String> handler) {
-        return addHandler(handler,
-                          ValueChangeEvent.getType());
-    }
-
-    public void showAssignmentsDialog() {
-        // Get data types to show the editor
-        getDataTypes();
-    }
-
-    protected void getDataTypes() {
-
-        final String simpleDataTypes = "Boolean:Boolean,Float:Float,Integer:Integer,Object:Object,String:String";
-        MessageBuilder.createCall(
-                new RemoteCallback<List<String>>() {
-                    public void callback(List<String> dataTypes) {
-                        String formattedDataTypes = formatDataTypes(dataTypes);
-                        String allDataTypes = simpleDataTypes + "," + formattedDataTypes;
-                        showDataIOEditor(allDataTypes.toString());
-                    }
-                },
-                new BusErrorCallback() {
-                    public boolean error(Message message,
-                                         Throwable t) {
-                        notification.fire(new NotificationEvent(StunnerFormsClientFieldsConstants.INSTANCE.Error_retrieving_datatypes(),
-                                                                NotificationEvent.NotificationType.ERROR));
-                        showDataIOEditor(simpleDataTypes);
-                        return false;
-                    }
-                },
-                DataTypesService.class).getDataTypeNames();
-    }
-
-    public void showDataIOEditor(final String datatypes) {
-        String taskName = getTaskName();
-        String processvars = getProcessVariables();
-
-        Map<String, String> assignmentsProperties = parseAssignmentsInfo();
-        String datainput = assignmentsProperties.get("datainput");
-        String datainputset = assignmentsProperties.get("datainputset");
-        String dataoutput = assignmentsProperties.get("dataoutput");
-        String dataoutputset = assignmentsProperties.get("dataoutputset");
-        String assignments = assignmentsProperties.get("assignments");
-
-        String disallowedpropertynames = getDisallowedPropertyNames();
-
-        String inputvars = null;
-        if (datainput != null) {
-            inputvars = datainput;
-        }
-        if (datainputset != null) {
-            inputvars = datainputset;
-        }
-        String outputvars = null;
-        if (dataoutput != null) {
-            outputvars = dataoutput;
-        }
-        if (dataoutputset != null) {
-            outputvars = dataoutputset;
-        }
-        AssignmentData assignmentData = new AssignmentData(inputvars,
-                                                           outputvars,
-                                                           processvars,
-                                                           assignments,
-                                                           datatypes,
-                                                           disallowedpropertynames);
-        assignmentData.setVariableCountsString(hasInputVars,
-                                               isSingleInputVar,
-                                               hasOutputVars,
-                                               isSingleOutputVar);
-
-        ActivityDataIOEditor.GetDataCallback callback = new ActivityDataIOEditor.GetDataCallback() {
-            @Override
-            public void getData(String assignmentDataJson) {
-                AssignmentData assignmentData = Marshalling.fromJSON(assignmentDataJson,
-                                                                     AssignmentData.class);
-                String assignmentsInfoString = createAssignmentsInfoString(assignmentData);
-                setValue(assignmentsInfoString,
-                         true);
-            }
-        };
-        activityDataIOEditor.setCallback(callback);
-
-        activityDataIOEditor.setAssignmentData(assignmentData);
-        activityDataIOEditor.setDisallowedPropertyNames(assignmentData.getDisallowedPropertyNames());
-        activityDataIOEditor.setInputAssignmentRows(assignmentData.getAssignmentRows(Variable.VariableType.INPUT));
-        activityDataIOEditor.setOutputAssignmentRows(assignmentData.getAssignmentRows(Variable.VariableType.OUTPUT));
-        activityDataIOEditor.setDataTypes(assignmentData.getDataTypes(),
-                                          assignmentData.getDataTypeDisplayNames());
-        activityDataIOEditor.setProcessVariables(assignmentData.getProcessVariableNames());
-        activityDataIOEditor.configureDialog(taskName,
-                                             hasInputVars,
-                                             isSingleInputVar,
-                                             hasOutputVars,
-                                             isSingleOutputVar);
-        activityDataIOEditor.show();
-    }
-
-    protected String getTaskName() {
-        String taskName = "Task";
-        if (bpmnModel != null && bpmnModel instanceof BaseTask) {
-            BaseTask task = (BaseTask) bpmnModel;
-            if (task.getGeneral() != null && task.getGeneral().getName() != null &&
-                    task.getGeneral().getName().getValue() != null && task.getGeneral().getName().getValue().length() > 0) {
-                taskName = task.getGeneral().getName().getValue();
-            }
-        }
-        return taskName;
-    }
-
-    protected String getProcessVariables() {
-        Diagram diagram = canvasSessionManager.getCurrentSession().getCanvasHandler().getDiagram();
-        Iterator<Element> it = diagram.getGraph().nodes().iterator();
-        while (it.hasNext()) {
-            Element element = it.next();
-            if (element.getContent() instanceof View) {
-                Object oDefinition = ((View) element.getContent()).getDefinition();
-                if (oDefinition instanceof BPMNDiagramImpl) {
-                    BPMNDiagramImpl bpmnDiagram = (BPMNDiagramImpl) oDefinition;
-                    ProcessVariables variables = bpmnDiagram.getProcessData().getProcessVariables();
-                    if (variables != null) {
-                        return variables.getValue();
-                    }
-                    break;
-                }
-            }
-        }
-        return null;
-    }
-
-    protected String formatDataTypes(final List<String> dataTypes) {
-        StringBuilder sb = new StringBuilder();
-        if (dataTypes != null && !dataTypes.isEmpty()) {
-            List<String> formattedDataTypes = new ArrayList<String>(dataTypes.size());
-            for (String dataType : dataTypes) {
-                int i = dataType.lastIndexOf('.');
-                StringBuilder formattedDataType = new StringBuilder(StringUtils.createDataTypeDisplayName(dataType));
-                formattedDataType.append(":").append(dataType);
-                formattedDataTypes.add(formattedDataType.toString());
-            }
-            Collections.sort(formattedDataTypes);
-            for (String formattedDataType : formattedDataTypes) {
-                sb.append(formattedDataType).append(',');
-            }
-            sb.setLength(sb.length() - 1);
-        }
-        return sb.toString();
-    }
-
-    protected Map<String, String> parseAssignmentsInfo() {
-        Map<String, String> properties = new HashMap<String, String>();
-        if (assignmentsInfo != null) {
-            String[] parts = assignmentsInfo.split("\\|");
-            if (parts.length > 0 && parts[0] != null && parts[0].length() > 0) {
-                properties.put("datainput",
-                               parts[0]);
-            }
-            if (parts.length > 1 && parts[1] != null && parts[1].length() > 0) {
-                properties.put("datainputset",
-                               parts[1]);
-            }
-            if (parts.length > 2 && parts[2] != null && parts[2].length() > 0) {
-                properties.put("dataoutput",
-                               parts[2]);
-            }
-            if (parts.length > 3 && parts[3] != null && parts[3].length() > 0) {
-                properties.put("dataoutputset",
-                               parts[3]);
-            }
-            if (parts.length > 4 && parts[4] != null && parts[4].length() > 0) {
-                properties.put("assignments",
-                               parts[4]);
-            }
-        }
-        return properties;
-    }
-
-    protected String createAssignmentsInfoString(final AssignmentData assignmentData) {
-        StringBuilder sb = new StringBuilder();
-        String dataInput = "";
-        String dataInputs = "";
-        String dataOutput = "";
-        String dataOutputs = "";
-        if (hasInputVars) {
-            if (isSingleInputVar) {
-                dataInput = assignmentData.getInputVariablesString();
-            } else {
-                dataInputs = assignmentData.getInputVariablesString();
-            }
-        }
-        if (hasOutputVars) {
-            if (isSingleOutputVar) {
-                dataOutput = assignmentData.getOutputVariablesString();
-            } else {
-                dataOutputs = assignmentData.getOutputVariablesString();
-            }
-        }
-
-        sb.append(dataInput).append('|').append(dataInputs).append('|').append(dataOutput).append('|').
-                append(dataOutputs)
-                .append('|').append(assignmentData.getAssignmentsString());
-        return sb.toString();
-    }
-
-    protected String getVariableCountsString(final String datainput,
+    String getVariableCountsString(final String datainput,
                                              final String datainputset,
                                              final String dataoutput,
                                              final String dataoutputset,
@@ -389,11 +197,253 @@ public class AssignmentsEditorWidget extends Composite implements HasValue<Strin
                                                       isSingleOutputVar);
     }
 
-    protected String getDisallowedPropertyNames() {
-        if (bpmnModel instanceof UserTask) {
-            return "GroupId,Skippable,Comment,Description,Priority,Content,TaskName,Locale,CreatedBy,NotCompletedReassign,NotStartedReassign,NotCompletedNotify,NotStartedNotify";
+    protected String getProcessVariables() {
+        Diagram diagram = canvasSessionManager.getCurrentSession().getCanvasHandler().getDiagram();
+        Node selectedElement = getSelectedElement();
+        String variables = VariableUtils.encodeProcessVariables(diagram, selectedElement);
+        StringBuilder sb = new StringBuilder();
+        if (!variables.isEmpty()) {
+            sb.append(variables);
+        }
+
+        String dataObjects =
+                DataObjectUtils.findDataObjects(canvasSessionManager.getCurrentSession(), graphUtils, getSelectedElement(), getParentIds()).stream()
+                        .map(AssignmentsEditorWidget::dataObjectToProcessVariableFormat)
+                        .collect(Collectors.joining(","));
+
+        if (!dataObjects.isEmpty()) {
+            sb.append(dataObjects);
+        }
+
+        return sb.toString();
+    }
+
+    String getDisallowedPropertyNames() {
+        if (bpmnModel instanceof BaseUserTask) {
+            return DEFAULT_IGNORED_PROPERTY_NAMES;
         } else {
             return "";
         }
     }
+
+    protected Node getSelectedElement() {
+        String elementUUID = getSelectedElementUUID(canvasSessionManager.getCurrentSession());
+        if (elementUUID != null) {
+            return canvasSessionManager.getCurrentSession().getCanvasHandler().getDiagram().getGraph().getNode(elementUUID);
+        }
+        return null;
+    }
+
+    Set<String> getParentIds() {
+        Set<String> parentIds = new HashSet<>();
+        final Node selectedElement = getSelectedElement();
+        Element parent = GraphUtils.getParent(selectedElement);
+
+        if (selectedElement != null) {
+            final String mainDiagramId = canvasSessionManager.getCurrentSession().getCanvasHandler().getDiagram().getMetadata().getCanvasRootUUID();
+            parentIds.add(parent.getUUID());
+
+            while (!parent.getUUID().equals(mainDiagramId)) {
+                parent = graphUtils.getParent(parent.asNode());
+                parentIds.add(parent.getUUID());
+            }
+        }
+        return parentIds;
+    }
+
+    private static String dataObjectToProcessVariableFormat(DataObject dataObject) {
+        return dataObject.getName().getValue() + ":" + dataObject.getType().getValue().getType();
+    }
+
+    protected String getSelectedElementUUID(ClientSession clientSession) {
+        if (clientSession instanceof EditorSession) {
+            final SelectionControl selectionControl = ((EditorSession) clientSession).getSelectionControl();
+            if (null != selectionControl) {
+                final Collection<String> selectedItems = selectionControl.getSelectedItems();
+                if (null != selectedItems && !selectedItems.isEmpty()) {
+                    return selectedItems.iterator().next();
+                }
+            }
+        }
+        return null;
+    }
+
+    protected boolean isBPMNDefinition(Node node) {
+        return node.getContent() instanceof View &&
+                ((View) node.getContent()).getDefinition() instanceof BPMNDefinition;
+    }
+
+    protected void setBPMNModel(final BPMNDefinition bpmnModel) {
+        this.bpmnModel = bpmnModel;
+
+        if (bpmnModel instanceof DataIOModel) {
+            DataIOModel dataIOModel = (DataIOModel) bpmnModel;
+            hasInputVars = dataIOModel.hasInputVars();
+            isSingleInputVar = dataIOModel.isSingleInputVar();
+            hasOutputVars = dataIOModel.hasOutputVars();
+            isSingleOutputVar = dataIOModel.isSingleOutputVar();
+        } else {
+            hasInputVars = false;
+            isSingleInputVar = false;
+            hasOutputVars = false;
+            isSingleOutputVar = false;
+        }
+    }
+
+    @Override
+    public HandlerRegistration addValueChangeHandler(final ValueChangeHandler<String> handler) {
+        return addHandler(handler,
+                          ValueChangeEvent.getType());
+    }
+
+    public void showAssignmentsDialog() {
+        // Get data types to show the editor
+        getDataTypes();
+    }
+
+    protected void getDataTypes() {
+        final String simpleDataTypes = "Boolean:Boolean,Float:Float,Integer:Integer,Object:Object,String:String";
+        clientDataTypesService
+                .call(getDiagramPath())
+                .then(dataTypes -> {
+                    String formattedDataTypes = formatDataTypes(dataTypes);
+                    String allDataTypes = simpleDataTypes + "," + formattedDataTypes;
+                    showDataIOEditor(allDataTypes);
+                    return null;
+                })
+                .catch_(exception -> {
+                    notification.fire(new NotificationEvent(StunnerFormsClientFieldsConstants.INSTANCE.Error_retrieving_datatypes(),
+                                                            NotificationEvent.NotificationType.ERROR));
+                    showDataIOEditor(simpleDataTypes);
+                    return null;
+                });
+    }
+
+    private Path getDiagramPath() {
+        final Diagram diagram = canvasSessionManager.getCurrentSession().getCanvasHandler().getDiagram();
+        return diagram.getMetadata().getPath();
+    }
+
+    public void showDataIOEditor(final String datatypes) {
+        String taskName = getTaskName();
+        String processvars = getProcessVariables();
+
+        Map<String, String> assignmentsProperties = AssignmentParser.parseAssignmentsInfo(assignmentsInfo);
+        String datainput = assignmentsProperties.get(AssignmentParser.DATAINPUT);
+        String datainputset = assignmentsProperties.get(AssignmentParser.DATAINPUTSET);
+        String dataoutput = assignmentsProperties.get(AssignmentParser.DATAOUTPUT);
+        String dataoutputset = assignmentsProperties.get(AssignmentParser.DATAOUTPUTSET);
+        String assignments = assignmentsProperties.get(AssignmentParser.ASSIGNMENTS);
+
+        String disallowedpropertynames = getDisallowedPropertyNames();
+
+        String inputvars = null;
+        if (datainput != null) {
+            inputvars = datainput;
+        }
+        if (datainputset != null) {
+            inputvars = datainputset;
+        }
+        String outputvars = null;
+        if (dataoutput != null) {
+            outputvars = dataoutput;
+        }
+        if (dataoutputset != null) {
+            outputvars = dataoutputset;
+        }
+        AssignmentData assignmentData = new AssignmentData(inputvars,
+                                                           outputvars,
+                                                           processvars,
+                                                           assignments,
+                                                           datatypes,
+                                                           disallowedpropertynames);
+        assignmentData.setVariableCountsString(hasInputVars,
+                                               isSingleInputVar,
+                                               hasOutputVars,
+                                               isSingleOutputVar);
+
+        ActivityDataIOEditor.GetDataCallback callback = assignmentDataJson -> {
+            AssignmentData assignmentData1 = Marshalling.fromJSON(assignmentDataJson,
+                                                                  AssignmentData.class);
+            String assignmentsInfoString = createAssignmentsInfoString(assignmentData1);
+            setValue(assignmentsInfoString,
+                     true);
+        };
+
+        activityDataIOEditor.setCallback(callback);
+        activityDataIOEditor.setAssignmentData(assignmentData);
+        activityDataIOEditor.setDisallowedPropertyNames(assignmentData.getDisallowedPropertyNames());
+        activityDataIOEditor.setInputAssignmentRows(assignmentData.getAssignmentRows(Variable.VariableType.INPUT));
+        activityDataIOEditor.setOutputAssignmentRows(assignmentData.getAssignmentRows(Variable.VariableType.OUTPUT));
+        activityDataIOEditor.setDataTypes(assignmentData.getDataTypes(),
+                                          assignmentData.getDataTypeDisplayNames());
+        activityDataIOEditor.setProcessVariables(assignmentData.getProcessVariableNames().stream()
+                                                         .distinct()
+                                                         .collect(Collectors.toList()));
+        activityDataIOEditor.configureDialog(taskName,
+                                             hasInputVars,
+                                             isSingleInputVar,
+                                             hasOutputVars,
+                                             isSingleOutputVar);
+        activityDataIOEditor.show();
+    }
+
+    public void setReadOnly(final boolean readOnly) {
+        activityDataIOEditor.setReadOnly(readOnly);
+    }
+
+    protected String getTaskName() {
+        String taskName = "Task";
+        if (bpmnModel instanceof BaseTask) {
+            BaseTask task = (BaseTask) bpmnModel;
+            if (task.getGeneral() != null && task.getGeneral().getName() != null &&
+                    task.getGeneral().getName().getValue() != null && task.getGeneral().getName().getValue().length() > 0) {
+                taskName = task.getGeneral().getName().getValue();
+            }
+        }
+        return taskName;
+    }
+
+    protected String formatDataTypes(final List<String> dataTypes) {
+        StringBuilder sb = new StringBuilder();
+        if (dataTypes != null && !dataTypes.isEmpty()) {
+            List<String> formattedDataTypes = new ArrayList<>(dataTypes.size());
+            for (String dataType : dataTypes) {
+                formattedDataTypes.add(StringUtils.createDataTypeDisplayName(dataType) + ":" + dataType);
+            }
+            Collections.sort(formattedDataTypes);
+            for (String formattedDataType : formattedDataTypes) {
+                sb.append(formattedDataType).append(',');
+            }
+            sb.setLength(sb.length() - 1);
+        }
+        return sb.toString();
+    }
+
+    protected String createAssignmentsInfoString(final AssignmentData assignmentData) {
+        StringBuilder sb = new StringBuilder();
+        String dataInput = "";
+        String dataInputs = "";
+        String dataOutput = "";
+        String dataOutputs = "";
+        if (hasInputVars) {
+            if (isSingleInputVar) {
+                dataInput = assignmentData.getInputVariablesString();
+            } else {
+                dataInputs = assignmentData.getInputVariablesString();
+            }
+        }
+        if (hasOutputVars) {
+            if (isSingleOutputVar) {
+                dataOutput = assignmentData.getOutputVariablesString();
+            } else {
+                dataOutputs = assignmentData.getOutputVariablesString();
+            }
+        }
+
+        sb.append(dataInput).append('|').append(dataInputs).append('|').append(dataOutput).append('|').
+                append(dataOutputs)
+                .append('|').append(assignmentData.getAssignmentsString());
+        return sb.toString();
+    }
 }
