@@ -72,8 +72,8 @@ import org.kie.workbench.common.stunner.bpmn.definition.property.task.RuleLangua
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.Script;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.ScriptTaskExecutionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.property.task.TaskName;
-import org.kie.workbench.common.stunner.bpmn.workitem.ServiceTask;
-import org.kie.workbench.common.stunner.bpmn.workitem.ServiceTaskExecutionSet;
+import org.kie.workbench.common.stunner.bpmn.workitem.CustomTask;
+import org.kie.workbench.common.stunner.bpmn.workitem.CustomTaskExecutionSet;
 import org.kie.workbench.common.stunner.core.graph.Edge;
 import org.kie.workbench.common.stunner.core.graph.Node;
 import org.kie.workbench.common.stunner.core.graph.content.view.View;
@@ -101,7 +101,7 @@ public abstract class BaseTaskConverter<U extends BaseUserTask<S>, S extends Bas
                 .when(e -> e instanceof org.eclipse.bpmn2.ServiceTask, this::serviceTaskResolver)
                 .when(e -> org.eclipse.bpmn2.impl.TaskImpl.class.equals(e.getClass()), this::defaultTaskResolver)
                 .missing(e -> e instanceof ManualTask, ManualTask.class)
-                .missing(e -> e instanceof ServiceTask, SendTask.class)
+                .missing(e -> e instanceof CustomTask, SendTask.class)
                 .missing(e -> e instanceof ReceiveTask, ReceiveTask.class)
                 .orElse(this::defaultTaskResolver)
                 .inputDecorator(BPMNElementDecorators.flowElementDecorator())
@@ -114,8 +114,8 @@ public abstract class BaseTaskConverter<U extends BaseUserTask<S>, S extends Bas
         return propertyReaderFactory
                 .ofCustom(task)
                 .map(p -> {
-                    final Node<View<ServiceTask>, Edge> node = factoryManager.newNode(task.getId(), ServiceTask.class);
-                    final ServiceTask definition = node.getContent().getDefinition();
+                    final Node<View<CustomTask>, Edge> node = factoryManager.newNode(task.getId(), CustomTask.class);
+                    final CustomTask definition = node.getContent().getDefinition();
                     definition.setName(p.getServiceTaskName());
                     definition.getTaskType().setRawType(p.getServiceTaskName());
                     definition.setDescription(p.getServiceTaskDescription());
@@ -131,7 +131,7 @@ public abstract class BaseTaskConverter<U extends BaseUserTask<S>, S extends Bas
                             p.getAssignmentsInfo()
                     ));
 
-                    definition.setExecutionSet(new ServiceTaskExecutionSet(
+                    definition.setExecutionSet(new CustomTaskExecutionSet(
                             new TaskName(p.getTaskName()),
                             new IsAsync(p.isAsync()),
                             new AdHocAutostart(p.isAdHocAutoStart()),
