@@ -24,7 +24,10 @@ import org.junit.runner.RunWith;
 import org.kie.workbench.common.stunner.bpmn.BPMNDefinitionSet;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagram;
 import org.kie.workbench.common.stunner.bpmn.definition.BPMNDiagramImpl;
+import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.DiagramSet;
+import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Id;
 import org.kie.workbench.common.stunner.bpmn.definition.property.diagram.Package;
+import org.kie.workbench.common.stunner.bpmn.definition.property.general.Name;
 import org.kie.workbench.common.stunner.core.diagram.Metadata;
 import org.kie.workbench.common.stunner.core.graph.Graph;
 import org.kie.workbench.common.stunner.core.graph.Node;
@@ -35,40 +38,76 @@ import org.kie.workbench.common.stunner.project.diagram.ProjectDiagram;
 import org.kie.workbench.common.stunner.project.diagram.ProjectMetadata;
 import org.mockito.Mock;
 import org.mockito.runners.MockitoJUnitRunner;
+import org.uberfire.backend.vfs.Path;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class BPMNProjectDiagramFactoryTest {
 
     private static final String NAME = "name1";
+    private static final String MODULE = "module";
     private static final String DIAGRAM_NODE_UUID = "dnuuid";
-    private static final String PKG = "org.kie.wb.common.stunner.bpmn.project.test";
+    private static final org.guvnor.common.services.project.model.Package PKG =
+            new org.guvnor.common.services.project.model.Package(mock(Path.class),
+                                                                 mock(Path.class),
+                                                                 mock(Path.class),
+                                                                 mock(Path.class),
+                                                                 mock(Path.class),
+                                                                 "packageName",
+                                                                 "packageCaption",
+                                                                 "");
 
     @Mock
-    ProjectMetadata metadata;
+    private ProjectMetadata metadata;
+
     @Mock
-    Graph graph;
+    private Graph graph;
+
     @Mock
-    Node diagramNode;
+    private Node diagramNode;
+
     @Mock
-    Bounds bounds;
-    BPMNDiagramImpl diagram;
-    private View<BPMNDiagram> diagramNodeContent;
+    private Bounds bounds;
+
+    private BPMNDiagramImpl diagram;
+
     private final List<Node> graphNodes = new ArrayList<>(1);
 
     private BPMNProjectDiagramFactoryImpl tested;
 
+    @Mock
+    private DiagramSet diagramSet;
+
+    private Id id;
+
+    private Name name;
+
+    private Package packageProperty;
+
     @Before
-    public void setup() throws Exception {
-        diagram = new BPMNDiagramImpl.BPMNDiagramBuilder().build();
-        diagramNodeContent = new ViewImpl<BPMNDiagram>(diagram,
-                                                       bounds);
+    public void setup() {
+        diagram = new BPMNDiagramImpl();
+        id = new Id();
+        name = new Name();
+        packageProperty = new Package();
+        diagram.setDiagramSet(diagramSet);
+        View<BPMNDiagram> diagramNodeContent = new ViewImpl<>(diagram, bounds);
         graphNodes.add(diagramNode);
         when(diagramNode.getUUID()).thenReturn(DIAGRAM_NODE_UUID);
         when(diagramNode.getContent()).thenReturn(diagramNodeContent);
         when(graph.nodes()).thenReturn(graphNodes);
+        when(diagramSet.getId()).thenReturn(id);
+        when(diagramSet.getPackageProperty()).thenReturn(packageProperty);
+        when(diagramSet.getName()).thenReturn(name);
+        when(metadata.getModuleName()).thenReturn(MODULE);
+
         tested = new BPMNProjectDiagramFactoryImpl();
     }
 
@@ -90,18 +129,29 @@ public class BPMNProjectDiagramFactoryTest {
     @SuppressWarnings("unchecked")
     public void testBuildNoPackageSpecified() {
         when(metadata.getProjectPackage()).thenReturn(null);
-        ProjectDiagram pdiagram = tested.build(NAME,
-                                               metadata,
-                                               graph);
+        ProjectDiagram pdiagram = tested.build(NAME, metadata, graph);
+
         assertNotNull(pdiagram);
-        assertEquals(graph,
-                     pdiagram.getGraph());
-        assertEquals(NAME,
-                     diagram.getDiagramSet().getId().getValue());
-        assertEquals(Package.DEFAULT_PACKAGE,
-                     diagram.getDiagramSet().getPackageProperty().getValue());
-        verify(metadata,
-               times(1)).setCanvasRootUUID(eq(DIAGRAM_NODE_UUID));
+        assertEquals(graph, pdiagram.getGraph());
+        assertEquals(MODULE + "." + NAME, id.getValue());
+        assertEquals(NAME, name.getValue());
+        assertEquals(Package.DEFAULT_PACKAGE, packageProperty.getValue());
+        verify(metadata, times(1)).setCanvasRootUUID(eq(DIAGRAM_NODE_UUID));
+    }
+
+    @Test
+    @SuppressWarnings("unchecked")
+    public void testBuildWithAttributesSet() {
+        final String id2 = "id";
+        final String name2 = "name2";
+
+        this.id.setValue(id2);
+        name.setValue(name2);
+
+        ProjectDiagram pdiagram = tested.build(NAME, metadata, graph);
+
+        assertEquals(id2, this.id.getValue());
+        assertEquals(name2, name.getValue());
     }
 
     @Test
@@ -109,18 +159,13 @@ public class BPMNProjectDiagramFactoryTest {
     public void testBuild() {
         final String pName = "p1";
         when(metadata.getProjectPackage()).thenReturn(PKG);
-        when(metadata.getProjectName()).thenReturn(pName);
-        ProjectDiagram pdiagram = tested.build(NAME,
-                                               metadata,
-                                               graph);
+        when(metadata.getModuleName()).thenReturn(pName);
+        ProjectDiagram pdiagram = tested.build(NAME, metadata, graph);
+
         assertNotNull(pdiagram);
-        assertEquals(graph,
-                     pdiagram.getGraph());
-        assertEquals(pName + "." + NAME,
-                     diagram.getDiagramSet().getId().getValue());
-        assertEquals(PKG,
-                     diagram.getDiagramSet().getPackageProperty().getValue());
-        verify(metadata,
-               times(1)).setCanvasRootUUID(eq(DIAGRAM_NODE_UUID));
+        assertEquals(graph, pdiagram.getGraph());
+        assertEquals(pName + "." + NAME, id.getValue());
+        assertEquals("packageName", packageProperty.getValue());
+        verify(metadata, times(1)).setCanvasRootUUID(eq(DIAGRAM_NODE_UUID));
     }
 }
